==> edge-login-ui-rn-1.5.0.tgz: package/lib/actions/PasswordRecoveryActions.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { openComposer } from 'react-native-email-link';
import Share from 'react-native-share';
import { sprintf } from 'sprintf-js';
import s from '../common/locales/strings';
import { showError } from '../components/services/AirshipInstance';
import { questionsList } from '../constants/recoveryQuestions';
/**
 * Prepares what is needed for the change recovery scene.
 */
export const initializeChangeRecovery = (account) => (dispatch, getState, imports) => __awaiter(void 0, void 0, void 0, function* () {
    const { context } = imports;
    // Get the user's questions:
    let userQuestions = [];
    const recoveryKey = account.recoveryKey;
    if (recoveryKey != null) {
        try {
            userQuestions = yield context.fetchRecovery2Questions(recoveryKey, account.username);
        }
        catch (error) {
            showError(error);
        }
    }
    dispatch({
        type: 'START_CHANGE_RECOVERY',
        data: { questionsList, userQuestions, account }
    });
});
function truncateUsername(username) {
    return username.slice(0, 2) + '***';
}
export function sendRecoveryEmail(emailAddress, username, recoveryKey, branding) {
    return __awaiter(this, void 0, void 0, function* () {
        const body = `${sprintf(s.strings.otp_email_body_branded, branding.appName)}
${truncateUsername(username)}

iOS
edge://recovery?token=${recoveryKey}

Android
https://deep.edge.app/recovery#${recoveryKey}

${s.strings.otp_email_body2}

${s.strings.recovery_token}: ${recoveryKey}

${sprintf(s.strings.otp_email_body3_branded, branding.appName)}`;
        return yield new Promise((resolve, reject) => {
            openComposer({
                to: emailAddress,
                subject: sprintf(s.strings.otp_email_subject_branded, branding.appName),
                body: body
            })
                .then(value => {
                resolve();
            })
                .catch((error) => {
                reject(error.message);
            });
        });
    });
}
export function shareRecovery(username, recoveryKey, branding) {
    return __awaiter(this, void 0, void 0, function* () {
        const body = sprintf(s.strings.otp_email_body_branded, branding.appName) +
            '\n' +
            truncateUsername(username) +
            `\n iOS: edge://recovery?token=${recoveryKey}` +
            `\n Android: https://deep.edge.app/recovery#${recoveryKey}\n` +
            s.strings.otp_email_body2 +
            `\n ${s.strings.recovery_token}: ${recoveryKey}\n` +
            sprintf(s.strings.otp_email_body3_branded, branding.appName);
        const title = sprintf(s.strings.otp_email_subject_branded, branding.appName);
        yield Share.open({ title, message: body }).catch(error => {
            if (!/User did not/.test(error === null || error === void 0 ? void 0 : error.message))
                throw error;
        });
    });
}

==> edge-login-ui-rn-2.12.0.tgz: package/lib/actions/PasswordRecoveryActions.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { openComposer } from 'react-native-email-link';
import Share from 'react-native-share';
import { sprintf } from 'sprintf-js';
import s from '../common/locales/strings';
import { showError } from '../components/services/AirshipInstance';
import { questionsList } from '../constants/recoveryQuestions';
/**
 * Prepares what is needed for the change recovery scene.
 */
export const initializeChangeRecovery = (account) => (dispatch, getState, imports) => __awaiter(void 0, void 0, void 0, function* () {
    const { context } = imports;
    // Get the user's questions:
    let userQuestions = [];
    const { recoveryKey, username } = account;
    if (recoveryKey != null && username != null) {
        try {
            userQuestions = yield context.fetchRecovery2Questions(recoveryKey, username);
        }
        catch (error) {
            showError(error);
        }
    }
    dispatch({
        type: 'NAVIGATE',
        data: {
            name: 'changeRecovery',
            params: { account, questionsList, userQuestions }
        }
    });
});
function truncateUsername(username) {
    return username.slice(0, 2) + '***';
}
export function sendRecoveryEmail(emailAddress, username, recoveryKey, branding) {
    return __awaiter(this, void 0, void 0, function* () {
        const body = `${sprintf(s.strings.otp_email_body_branded, branding.appName)}
${truncateUsername(username)}

iOS
edge://recovery?token=${recoveryKey}

Android
https://deep.edge.app/recovery#${recoveryKey}

${s.strings.otp_email_body2}

${s.strings.recovery_token}: ${recoveryKey}

${sprintf(s.strings.otp_email_body3_branded, branding.appName)}`;
        return yield new Promise((resolve, reject) => {
            openComposer({
                to: emailAddress,
                subject: sprintf(s.strings.otp_email_subject_branded, branding.appName),
                body: body
            })
                .then(value => {
                resolve();
            })
                .catch((error) => {
                reject(error.message);
            });
        });
    });
}
export function shareRecovery(username, recoveryKey, branding) {
    return __awaiter(this, void 0, void 0, function* () {
        const body = sprintf(s.strings.otp_email_body_branded, branding.appName) +
            '\n' +
            truncateUsername(username) +
            `\n iOS: edge://recovery?token=${recoveryKey}` +
            `\n Android: https://deep.edge.app/recovery#${recoveryKey}\n` +
            s.strings.otp_email_body2 +
            `\n ${s.strings.recovery_token}: ${recoveryKey}\n` +
            sprintf(s.strings.otp_email_body3_branded, branding.appName);
        const title = sprintf(s.strings.otp_email_subject_branded, branding.appName);
        yield Share.open({ title, message: body }).catch(error => {
            if (!/User did not/.test(error === null || error === void 0 ? void 0 : error.message))
                throw error;
        });
    });
}
